@@ -401,7 +401,7 @@ def update_module_files(yaml_path, local_yaml_path, branch_result, n_branch, mod
         before_branch = podfile_module_data['branch']
     # 转换成模型数组
     conver_deplist = load_yaml(dependenceList)
-    print("origin=======" + str(dependenceList))
+    # print("origin=======" + str(dependenceList))
 
     index = 0
     for a in conver_deplist:
@@ -412,7 +412,7 @@ def update_module_files(yaml_path, local_yaml_path, branch_result, n_branch, mod
                                "inhibit_warnings": a.inhibit_warnings}
                 dependenceList[index] = module_dict
         index += 1
-    print("convert=======" + str(dependenceList))
+    # print("convert=======" + str(dependenceList))
     except_list = [
         module for module in branch_result if module.module not in [
             pod.module for pod in conver_deplist]]
@@ -426,7 +426,7 @@ def update_module_files(yaml_path, local_yaml_path, branch_result, n_branch, mod
             }
             dependenceList.append(module_dict)
 
-    print("except_list=======" + str(dependenceList))
+    # print("except_list=======" + str(dependenceList))
     if not (before_branch and len(before_branch) > 0):
         before_branch = n_branch
     podfile_data = {"version": "1.0.0", "branch": str(before_branch), "dependencies": dependenceList}
@@ -538,7 +538,7 @@ def auto_release_path(filepath, git, pod, branch, new_tag):
     git_push_command = "git push origin master"
     # 用newTag来修改podspec中version
     os.system(git_clone_command)
-    print("执行 " + git_clone_command)
+    # print("执行 " + git_clone_command)
 
     # 获取开发分支最后一次提交的信息
     repogit = RepoGit(proj_path=filepath)
@@ -551,11 +551,11 @@ def auto_release_path(filepath, git, pod, branch, new_tag):
     os.system("pwd")
     os.system("ls")
     os.system(git_add_command)
-    print("执行 " + git_add_command)
+    # print("执行 " + git_add_command)
     os.system(git_commit_command)
-    print("执行 " + git_commit_command)
+    # print("执行 " + git_commit_command)
     pul_status = os.system(git_pull_command)
-    print("执行 " + git_pull_command)
+    # print("执行 " + git_pull_command)
     if not pul_status == 0:
         print("代码冲突了")
         return ""
@@ -572,10 +572,10 @@ def auto_release_path(filepath, git, pod, branch, new_tag):
 
     update_versionfor_podspec(pod + ".podspec", new_tag_p)
     os.system(git_add_command)
-    print("执行 " + git_add_command)
+    # print("执行 " + git_add_command)
     os.system(git_commit_command)
-    print("执行 " + git_commit_command)
-    print("代码已经提交到master")
+    # print("执行 " + git_commit_command)
+    # print("代码已经提交到master")
     # git pull branch 代码
 
     full_tag_message = '自动Tag 分支: {0} '.format(branch)
@@ -586,7 +586,7 @@ def auto_release_path(filepath, git, pod, branch, new_tag):
     git_push_tag_command = "git push origin {0} ".format(new_tag_p)
     os.system(git_push_tag_command)
     os.system(git_push_command)
-    print("执行 " + git_push_command)
+    # print("执行 " + git_push_command)
     return new_tag_p
 
 
